@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
    Copyright 2009 Thomas McGuire <mcguire@kde.org>
 
    This program is free software; you can redistribute it and/or
@@ -183,8 +183,7 @@ QMap<QString, QString> parseMailtoUrl(const QUrl &url)
         values.insertMulti(queryItem.first, queryItem.second);
     }
 
-    QStringList to;
-    to << KEmailAddress::decodeMailtoUrl(url);
+    QStringList to = {KEmailAddress::decodeMailtoUrl(url)};
 
     const QString toStr = values.value(QStringLiteral("to"));
     if (!toStr.isEmpty()) {
@@ -294,9 +293,9 @@ QString quoteHtmlChars(const QString &str, bool removeLineBreaks)
 {
     QString result;
 
-    unsigned int strLength(str.length());
+    int strLength(str.length());
     result.reserve(6 * strLength); // maximal possible length
-    for (unsigned int i = 0; i < strLength; ++i) {
+    for (int i = 0; i < strLength; ++i) {
         switch (str[i].toLatin1()) {
         case '<':
             result += QLatin1String("&lt;");
@@ -382,15 +381,22 @@ QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList, Displa
     bool expandableInserted = false;
     KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
 
+    const QString i18nMe = i18nc("signal that this email is defined in my identity", "Me");
+    const bool onlyOneIdentity = (im->identities().count() == 1);
     for (const KMime::Types::Mailbox &mailbox : mailboxList) {
-        if (!mailbox.prettyAddress().isEmpty()) {
+        const QString prettyAddressStr = mailbox.prettyAddress();
+        if (!prettyAddressStr.isEmpty()) {
             numberAddresses++;
             if (expandable == ExpandableAddresses && !expandableInserted && numberAddresses > collapseNumber) {
-                result = QLatin1String("<span id=\"icon") + fieldName + QLatin1String("\"></span>") + result;
-                const QString visibility = QStringLiteral(" style=\"display:none;\"");
-
-                result += QLatin1String("<span id=\"dots") + fieldName + QLatin1String("\">...</span><span id=\"hidden") + fieldName + QLatin1String("\")") + visibility + QLatin1String(">");
+                const QString actualListAddress = result;
+                QString shortListAddress = actualListAddress;
+                if (link == ShowLink) {
+                    shortListAddress.truncate(result.length() - 2);
+                }
+                result = QStringLiteral("<span><input type=\"checkbox\" class=\"addresslist_checkbox\" id=\"%1\" checked=\"checked\"/><span class=\"short%1\">").arg(fieldName) + shortListAddress;
+                result += QStringLiteral("<label class=\"addresslist_label_short\" for=\"%1\"></label></span>").arg(fieldName);
                 expandableInserted = true;
+                result += QStringLiteral("<span class=\"full%1\">").arg(fieldName) + actualListAddress;
             }
 
             if (link == ShowLink) {
@@ -398,13 +404,13 @@ QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList, Displa
                           + QString::fromLatin1(QUrl::toPercentEncoding(KEmailAddress::encodeMailtoUrl(mailbox.prettyAddress(KMime::Types::Mailbox::QuoteWhenNecessary)).path()))
                           + QLatin1String("\" ") + cssStyle + QLatin1Char('>');
             }
-            const bool foundMe = (im->identities().count() == 1) && (im->identityForAddress(mailbox.prettyAddress()) != KIdentityManagement::Identity::null());
-            const QString i18nMe = i18nc("signal that this email is defined in my identity", "Me");
+            const bool foundMe = onlyOneIdentity && (im->identityForAddress(prettyAddressStr) != KIdentityManagement::Identity::null());
+
             if (display == DisplayNameOnly) {
                 if (!mailbox.name().isEmpty()) { // Fallback to the email address when the name is not set.
                     result += foundMe ? i18nMe : quoteHtmlChars(mailbox.name(), true);
                 } else {
-                    result += foundMe ? i18nMe : quoteHtmlChars(mailbox.prettyAddress(), true);
+                    result += foundMe ? i18nMe : quoteHtmlChars(prettyAddressStr, true);
                 }
             } else {
                 result += foundMe ? i18nMe : quoteHtmlChars(mailbox.prettyAddress(KMime::Types::Mailbox::QuoteWhenNecessary), true);
@@ -415,13 +421,12 @@ QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList, Displa
         }
     }
 
-    // cut of the trailing ", "
     if (link == ShowLink) {
         result.truncate(result.length() - 2);
     }
 
     if (expandableInserted) {
-        result += QLatin1String("</span>");
+        result += QStringLiteral("<label class=\"addresslist_label_full\" for=\"%1\"></label></span>").arg(fieldName);
     }
     return result;
 }
@@ -587,8 +592,8 @@ QString formatQuotePrefix(const QString &wildString, const QString &fromDisplayS
         return wildString;
     }
 
-    unsigned int strLength(wildString.length());
-    for (uint i = 0; i < strLength;) {
+    int strLength(wildString.length());
+    for (int i = 0; i < strLength;) {
         QChar ch = wildString[i++];
         if (ch == QLatin1Char('%') && i < strLength) {
             ch = wildString[i++];
@@ -599,8 +604,8 @@ QString formatQuotePrefix(const QString &wildString, const QString &fromDisplayS
                     break;
                 }
 
-                uint j = 0;
-                const unsigned int strLength(fromDisplayString.length());
+                int j = 0;
+                const int strLength(fromDisplayString.length());
                 for (; j < strLength && fromDisplayString[j] > QLatin1Char(' '); ++j) {
                 }
                 for (; j < strLength && fromDisplayString[j] <= QLatin1Char(' '); ++j) {
