@@ -27,12 +27,8 @@
 
 #include "messagelist_debug.h"
 
-namespace MessageList
-{
-
-namespace Core
-{
-
+namespace MessageList {
+namespace Core {
 class RowShift
 {
 public:
@@ -42,22 +38,21 @@ public:
 
 public:
     RowShift(int minRowIndex, int shift, QHash< int, ModelInvariantIndex * > *invariantHash)
-        : mMinimumRowIndex(minRowIndex), mShift(shift), mInvariantHash(invariantHash)
+        : mMinimumRowIndex(minRowIndex)
+        , mShift(shift)
+        , mInvariantHash(invariantHash)
     {
     }
 
     ~RowShift()
     {
-        QHash< int, ModelInvariantIndex * >::ConstIterator end(mInvariantHash->constEnd());
-        for (QHash< int, ModelInvariantIndex * >::ConstIterator it = mInvariantHash->constBegin(); it != end; ++it) {
-            (*it)->d->setRowMapper(Q_NULLPTR);
+        for (const auto idx : qAsConst(*mInvariantHash)) {
+            idx->d->setRowMapper(nullptr);
         }
         delete mInvariantHash;
     }
 };
-
 } // namespace Core
-
 } // namespace MessageList
 
 using namespace MessageList::Core;
@@ -73,8 +68,7 @@ ModelInvariantRowMapper::ModelInvariantRowMapper()
     d->mLazyUpdateChunkInterval = 50;
     d->mLazyUpdateIdleInterval = 50;
 
-    connect(d->mUpdateTimer, SIGNAL(timeout()),
-            SLOT(slotPerformLazyUpdate()));
+    connect(d->mUpdateTimer, &QTimer::timeout, this, [this]() { d->slotPerformLazyUpdate(); });
 }
 
 ModelInvariantRowMapper::~ModelInvariantRowMapper()
@@ -84,9 +78,8 @@ ModelInvariantRowMapper::~ModelInvariantRowMapper()
     }
 
     // FIXME: optimize this (it CAN be optimized)
-    QHash< int, ModelInvariantIndex * >::ConstIterator end(d->mCurrentInvariantHash->constEnd());
-    for (QHash< int, ModelInvariantIndex * >::ConstIterator it = d->mCurrentInvariantHash->constBegin(); it != end; ++it) {
-        (*it)->d->setRowMapper(Q_NULLPTR);
+    for (const auto idx : qAsConst(*d->mCurrentInvariantHash)) {
+        idx->d->setRowMapper(nullptr);
     }
     delete d->mCurrentInvariantHash;
 
@@ -112,7 +105,7 @@ void ModelInvariantRowMapperPrivate::killFirstRowShift()
     mRemovedShiftCount++;
     if (mRowShiftList->isEmpty()) {
         delete mRowShiftList;
-        mRowShiftList = Q_NULLPTR;
+        mRowShiftList = nullptr;
     }
 }
 
@@ -181,20 +174,20 @@ void ModelInvariantRowMapperPrivate::updateModelInvariantIndex(int modelIndexRow
 ModelInvariantIndex *ModelInvariantRowMapperPrivate::modelIndexRowToModelInvariantIndexInternal(int modelIndexRow, bool updateIfNeeded)
 {
     // First of all look it up in the current hash
-    ModelInvariantIndex *invariant = mCurrentInvariantHash->value(modelIndexRow, Q_NULLPTR);
+    ModelInvariantIndex *invariant = mCurrentInvariantHash->value(modelIndexRow, nullptr);
     if (invariant) {
         return invariant;    // found: was up to date
     }
 
     // Go backward in history by unapplying changes
     if (!mRowShiftList) {
-        return Q_NULLPTR;    // not found (not requested yet or invalid index at all)
+        return nullptr;    // not found (not requested yet or invalid index at all)
     }
 
     int idx = mRowShiftList->count();
     if (idx == 0) {
         Q_ASSERT(false);
-        return Q_NULLPTR; // should never happen (mRowShiftList should have been 0), but well...
+        return nullptr; // should never happen (mRowShiftList should have been 0), but well...
     }
     idx--;
 
@@ -222,7 +215,7 @@ ModelInvariantIndex *ModelInvariantRowMapperPrivate::modelIndexRowToModelInvaria
             previousIndexRow = potentialPreviousModelIndexRow;
         }
 
-        invariant = shift->mInvariantHash->value(previousIndexRow, Q_NULLPTR);
+        invariant = shift->mInvariantHash->value(previousIndexRow, nullptr);
         if (invariant) {
             // found at this level in history
             if (updateIfNeeded) { // update it too
@@ -236,7 +229,7 @@ ModelInvariantIndex *ModelInvariantRowMapperPrivate::modelIndexRowToModelInvaria
 
     qCWarning(MESSAGELIST_LOG) << "Requested invariant for storage row index "
                                << modelIndexRow << " not found in history";
-    return Q_NULLPTR; // not found in history
+    return nullptr; // not found in history
 }
 
 void ModelInvariantRowMapper::setLazyUpdateChunkInterval(int chunkInterval)
@@ -344,7 +337,7 @@ int ModelInvariantRowMapper::modelInvariantIndexToModelIndexRow(ModelInvariantIn
 void ModelInvariantRowMapper::createModelInvariantIndex(int modelIndexRow, ModelInvariantIndex *invariantToFill)
 {
     // The user is athemeg for the invariant of the item that is at the CURRENT modelIndexRow.
-    Q_ASSERT(invariantToFill->d->rowMapper() == 0);
+    Q_ASSERT(invariantToFill->d->rowMapper() == nullptr);
 
     // Plain new invariant. Fill it and add to the current hash.
     invariantToFill->d->setModelIndexRowAndRowMapperSerial(modelIndexRow, d->mCurrentShiftSerial);
@@ -364,14 +357,14 @@ QList< ModelInvariantIndex * > *ModelInvariantRowMapper::modelIndexRowRangeToMod
 {
     if (!d->mRowShiftList) {
         if (d->mCurrentInvariantHash->isEmpty()) {
-            return Q_NULLPTR;    // no invariants emitted, even if rows are changed, no invariant is affected.
+            return nullptr;    // no invariants emitted, even if rows are changed, no invariant is affected.
         }
     }
 
     // Find the invariants in range.
     // It's somewhat impossible to split this in chunks.
 
-    QList< ModelInvariantIndex * > *invariantList = new QList< ModelInvariantIndex * >();
+    auto invariantList = new QList< ModelInvariantIndex * >();
 
     const int end = startIndexRow + count;
     for (int idx = startIndexRow; idx < end; idx++) {
@@ -383,7 +376,7 @@ QList< ModelInvariantIndex * > *ModelInvariantRowMapper::modelIndexRowRangeToMod
 
     if (invariantList->isEmpty()) {
         delete invariantList;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     return invariantList;
@@ -444,7 +437,6 @@ void ModelInvariantRowMapper::modelRowsInserted(int modelIndexRowPosition, int c
         }
 
         d->slotPerformLazyUpdate();
-
     } else {
         // Make sure we'll get a lazy update somewhere in the future
         if (!d->mUpdateTimer->isActive()) {
@@ -464,7 +456,7 @@ QList< ModelInvariantIndex * > *ModelInvariantRowMapper::modelRowsRemoved(int mo
 
     if (!d->mRowShiftList) {
         if (d->mCurrentInvariantHash->isEmpty()) {
-            return Q_NULLPTR;    // no invariants emitted, even if rows are changed, no invariant is affected.
+            return nullptr;    // no invariants emitted, even if rows are changed, no invariant is affected.
         }
         // some invariants might be affected
     }
@@ -498,7 +490,7 @@ QList< ModelInvariantIndex * > *ModelInvariantRowMapper::modelRowsRemoved(int mo
     // In most cases it's a relatively small sweep (and it's done once).
     // It's somewhat impossible to split this in chunks.
 
-    QList< ModelInvariantIndex * > *deadInvariants = new QList< ModelInvariantIndex * >();
+    auto deadInvariants = new QList< ModelInvariantIndex * >();
 
     const int end = modelIndexRowPosition + count;
     for (int idx = modelIndexRowPosition; idx < end; idx++) {
@@ -507,7 +499,7 @@ QList< ModelInvariantIndex * > *ModelInvariantRowMapper::modelRowsRemoved(int mo
         ModelInvariantIndex *dyingInvariant = d->modelIndexRowToModelInvariantIndexInternal(idx, false);
         if (dyingInvariant) {
             d->indexDead(dyingInvariant);   // will remove from this mapper hashes
-            dyingInvariant->d->setRowMapper(Q_NULLPTR);   // invalidate!
+            dyingInvariant->d->setRowMapper(nullptr);   // invalidate!
             deadInvariants->append(dyingInvariant);
         } else {
             // got no dying invariant
@@ -522,7 +514,7 @@ QList< ModelInvariantIndex * > *ModelInvariantRowMapper::modelRowsRemoved(int mo
             if (deadInvariants->isEmpty()) {
                 // should never happen, but well...
                 delete deadInvariants;
-                return Q_NULLPTR;
+                return nullptr;
             }
             return deadInvariants;
         }
@@ -547,7 +539,6 @@ QList< ModelInvariantIndex * > *ModelInvariantRowMapper::modelRowsRemoved(int mo
         }
 
         d->slotPerformLazyUpdate();
-
     } else {
         // Make sure we'll get a lazy update somewhere in the future
         if (!d->mUpdateTimer->isActive()) {
@@ -558,7 +549,7 @@ QList< ModelInvariantIndex * > *ModelInvariantRowMapper::modelRowsRemoved(int mo
     if (deadInvariants->isEmpty()) {
         // should never happen, but well...
         delete deadInvariants;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     return deadInvariants;
@@ -569,8 +560,8 @@ void ModelInvariantRowMapper::modelReset()
     // FIXME: optimize this (it probably can be optimized by providing a more complex user interface)
     QHash< int, ModelInvariantIndex * >::ConstIterator end(d->mCurrentInvariantHash->constEnd());
 
-    for (QHash< int, ModelInvariantIndex * >::ConstIterator it = d->mCurrentInvariantHash->constBegin(); it != end; ++it) {
-        (*it)->d->setRowMapper(Q_NULLPTR);
+    for (const auto idx : qAsConst(*d->mCurrentInvariantHash)) {
+        idx->d->setRowMapper(nullptr);
     }
     d->mCurrentInvariantHash->clear();
 
@@ -580,7 +571,7 @@ void ModelInvariantRowMapper::modelReset()
         }
 
         delete d->mRowShiftList;
-        d->mRowShiftList = Q_NULLPTR;
+        d->mRowShiftList = nullptr;
     }
 
     d->mCurrentShiftSerial = 0;
@@ -614,8 +605,8 @@ void ModelInvariantRowMapperPrivate::slotPerformLazyUpdate()
         RowShift *shift = mRowShiftList->at(0);
 
         // and update the invariants that belong to it
-        QHash< int, ModelInvariantIndex * >::Iterator it = shift->mInvariantHash->begin();
-        QHash< int, ModelInvariantIndex * >::Iterator end = shift->mInvariantHash->end();
+        auto it = shift->mInvariantHash->begin();
+        auto end = shift->mInvariantHash->end();
 
         while (it != end) {
             ModelInvariantIndex *invariant = *it;
